@@ -47,15 +47,15 @@ where
     #[emitter]
     fn emit_rule(&mut self, n: &Rule) -> Result {
         match n {
-            Rule::Style(n) => emit!(self, n),
+            Rule::QualifiedRule(n) => emit!(self, n),
             Rule::AtRule(n) => emit!(self, n),
             Rule::Invalid(n) => emit!(self, n),
         }
     }
 
     #[emitter]
-    fn emit_style_rule(&mut self, n: &StyleRule) -> Result {
-        emit!(self, n.selectors);
+    fn emit_qualified_rule(&mut self, n: &QualifiedRule) -> Result {
+        emit!(self, n.prelude);
         space!(self);
         emit!(self, n.block);
     }
@@ -151,7 +151,7 @@ where
     #[emitter]
     fn emit_keyframe_selector(&mut self, n: &KeyframeSelector) -> Result {
         match n {
-            KeyframeSelector::Id(n) => emit!(self, n),
+            KeyframeSelector::Ident(n) => emit!(self, n),
             KeyframeSelector::Percent(n) => emit!(self, n),
         }
     }
@@ -266,7 +266,7 @@ where
             Value::Number(n) => emit!(self, n),
             Value::Percent(n) => emit!(self, n),
             Value::Hash(n) => emit!(self, n),
-            Value::Text(n) => emit!(self, n),
+            Value::Ident(n) => emit!(self, n),
             Value::Str(n) => emit!(self, n),
             Value::Fn(n) => emit!(self, n),
             Value::Bin(n) => emit!(self, n),
@@ -298,7 +298,7 @@ where
     #[emitter]
     fn emit_media_query(&mut self, n: &MediaQuery) -> Result {
         match n {
-            MediaQuery::Text(n) => emit!(self, n),
+            MediaQuery::Ident(n) => emit!(self, n),
             MediaQuery::And(n) => emit!(self, n),
             MediaQuery::Or(n) => emit!(self, n),
             MediaQuery::Not(n) => emit!(self, n),
@@ -352,7 +352,7 @@ where
     }
 
     #[emitter]
-    fn emit_text(&mut self, n: &Text) -> Result {
+    fn emit_ident(&mut self, n: &Ident) -> Result {
         self.wr.write_raw(Some(n.span), &n.raw)?;
     }
 
@@ -758,7 +758,7 @@ where
     fn emit_attr_selector_value(&mut self, n: &AttrSelectorValue) -> Result {
         match n {
             AttrSelectorValue::Str(n) => emit!(self, n),
-            AttrSelectorValue::Text(n) => emit!(self, n),
+            AttrSelectorValue::Ident(n) => emit!(self, n),
         }
     }
 
@@ -788,18 +788,56 @@ where
         punct!(self, "]");
     }
 
+    #[emitter]
+    fn emit_nth(&mut self, n: &Nth) -> Result {
+        emit!(self, n.nth);
+
+        if n.selector_list.is_some() {
+            emit!(self, n.selector_list);
+        }
+    }
+
+    #[emitter]
+    fn emit_an_plus_b(&mut self, n: &AnPlusB) -> Result {
+        if let Some(a_raw) = &n.a_raw {
+            self.wr.write_raw(Some(n.span), a_raw)?;
+            punct!(self, "n");
+        }
+
+        if let Some(b_raw) = &n.b_raw {
+            self.wr.write_raw(Some(n.span), b_raw)?;
+        }
+    }
+
+    #[emitter]
+    fn emit_nth_value(&mut self, n: &NthValue) -> Result {
+        match n {
+            NthValue::AnPlusB(n) => emit!(self, n),
+            NthValue::Ident(n) => emit!(self, n),
+        }
+    }
+
+    #[emitter]
+    fn emit_pseudo_selector_children(&mut self, n: &PseudoSelectorChildren) -> Result {
+        match n {
+            PseudoSelectorChildren::Nth(n) => emit!(self, n),
+            PseudoSelectorChildren::Tokens(n) => emit!(self, n),
+        }
+    }
+
     #[emitter]
     fn emit_pseudo_selector(&mut self, n: &PseudoSelector) -> Result {
         punct!(self, ":");
+
         if n.is_element {
             punct!(self, ":");
         }
 
         emit!(self, n.name);
 
-        if !n.args.tokens.is_empty() {
+        if n.children.is_some() {
             punct!(self, "(");
-            emit!(self, n.args);
+            emit!(self, n.children);
             punct!(self, ")");
         }
     }
